@@ -1,8 +1,9 @@
 import uuid
-from dataclasses import dataclass, field
+from dataclasses import dataclass
 
 @dataclass
 class Equipment:
 
     id: uuid.UUID
-    name: str
\ No newline at end of file
+    name: str
+    active: bool
